@@ -1,8 +1,8 @@
-#'  Term frequency-inverse document frequency of tokens
+#' Term Frequency-Inverse Document Frequency of Tokens
 #'
-#' `step_tfidf` creates a *specification* of a recipe step that
-#'  will convert a [tokenlist] into multiple variables containing
-#'  the term frequency-inverse document frequency of tokens.
+#' `step_tfidf` creates a *specification* of a recipe step that will convert a
+#' [`token`][tokenlist()] variable into multiple variables containing the term
+#' frequency-inverse document frequency of tokens.
 #'
 #' @template args-recipe
 #' @template args-dots
@@ -10,24 +10,26 @@
 #' @template args-trained
 #' @template args-columns
 #' @param vocabulary A character vector of strings to be considered.
-#' @param res The words that will be used to calculate the term
-#'  frequency will be stored here once this preprocessing step has
-#'  be trained by [prep.recipe()].
+#' @param res The words that will be used to calculate the term frequency will
+#'   be stored here once this preprocessing step has be trained by
+#'   [prep.recipe()].
 #' @param smooth_idf TRUE smooth IDF weights by adding one to document
-#'  frequencies, as if an extra document was seen containing every term
-#'  in the collection exactly once. This prevents division by zero.
-#' @param norm A character, defines the type of normalization to apply to
-#'  term vectors. "l1" by default, i.e., scale by the number of words in the
-#'  document. Must be one of c("l1", "l2", "none").
+#'   frequencies, as if an extra document was seen containing every term in the
+#'   collection exactly once. This prevents division by zero.
+#' @param norm A character, defines the type of normalization to apply to term
+#'   vectors. "l1" by default, i.e., scale by the number of words in the
+#'   document. Must be one of c("l1", "l2", "none").
 #' @param sublinear_tf A logical, apply sublinear term-frequency scaling, i.e.,
-#'  replace the term frequency with 1 + log(TF). Defaults to FALSE.
+#'   replace the term frequency with 1 + log(TF). Defaults to FALSE.
 #' @template args-prefix
+#' @template args-keep_original_cols
 #' @template args-skip
 #' @template args-id
-#' 
+#'
 #' @template returns
-#' 
+#'
 #' @details
+#'
 #' It is strongly advised to use [step_tokenfilter] before using [step_tfidf] to
 #' limit the number of variables created; otherwise you may run into memory
 #' issues. A good strategy is to start with a low token count and increase
@@ -39,39 +41,43 @@
 #' Term frequency measures how many times each token appears in each
 #' observation.
 #'
-#' Inverse document frequency is a measure of how informative a word
-#' is, e.g., how common or rare the word is across all the
-#' observations. If a word appears in all the observations it might not
-#' give that much insight, but if it only appears in some it might help
-#' differentiate between observations.
+#' Inverse document frequency is a measure of how informative a word is, e.g.,
+#' how common or rare the word is across all the observations. If a word appears
+#' in all the observations it might not give that much insight, but if it only
+#' appears in some it might help differentiate between observations.
 #'
-#' The IDF is defined as follows: idf = log(1 + (# documents in the corpus) /
-#' (# documents where the term appears))
+#' The IDF is defined as follows: idf = log(1 + (# documents in the corpus) / (#
+#' documents where the term appears))
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
+#' (the selectors or variables selected).
 #'
 #' @template details-prefix
-#' 
-#' @seealso [step_tokenize()] to turn character into tokenlist.
-#' @family tokenlist to numeric steps
-#' 
+#'
+#' @seealso [step_tokenize()] to turn characters into [`tokens`][tokenlist()]
+#' @family Steps for Numeric Variables From Tokens
+#'   
 #' @examples
 #' \donttest{
 #' library(recipes)
 #' library(modeldata)
-#' data(okc_text)
+#' data(tate_text)
 #'
-#' okc_rec <- recipe(~., data = okc_text) %>%
-#'   step_tokenize(essay0) %>%
-#'   step_tfidf(essay0)
+#' tate_rec <- recipe(~., data = tate_text) %>%
+#'   step_tokenize(medium) %>%
+#'   step_tfidf(medium)
 #'
-#' okc_obj <- okc_rec %>%
+#' tate_obj <- tate_rec %>%
 #'   prep()
 #'
-#' bake(okc_obj, okc_text)
+#' bake(tate_obj, tate_text)
 #'
-#' tidy(okc_rec, number = 2)
-#' tidy(okc_obj, number = 2)
+#' tidy(tate_rec, number = 2)
+#' tidy(tate_obj, number = 2)
 #' }
-#' 
+#'
 #' @export
 step_tfidf <-
   function(recipe,
@@ -85,12 +91,13 @@ step_tfidf <-
            norm = "l1",
            sublinear_tf = FALSE,
            prefix = "tfidf",
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("tfidf")) {
     add_step(
       recipe,
       step_tfidf_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         vocabulary = vocabulary,
@@ -100,6 +107,7 @@ step_tfidf <-
         sublinear_tf = sublinear_tf,
         columns = columns,
         prefix = prefix,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -108,7 +116,7 @@ step_tfidf <-
 
 step_tfidf_new <-
   function(terms, role, trained, columns, vocabulary, res, smooth_idf, norm,
-           sublinear_tf, prefix, skip, id) {
+           sublinear_tf, prefix, keep_original_cols, skip, id) {
     step(
       subclass = "tfidf",
       terms = terms,
@@ -121,6 +129,7 @@ step_tfidf_new <-
       norm = norm,
       sublinear_tf = sublinear_tf,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -128,7 +137,7 @@ step_tfidf_new <-
 
 #' @export
 prep.step_tfidf <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_list(training[, col_names])
 
@@ -150,6 +159,7 @@ prep.step_tfidf <- function(x, training, info = NULL, ...) {
     norm = x$norm,
     sublinear_tf = x$sublinear_tf,
     prefix = x$prefix,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -170,8 +180,11 @@ bake.step_tfidf <- function(object, new_data, ...) {
       object$sublinear_tf
     )
 
-    new_data <-
-      new_data[, !(colnames(new_data) %in% col_names[i]), drop = FALSE]
+    keep_original_cols <- get_keep_original_cols(object)
+    if (!keep_original_cols) {
+      new_data <- 
+        new_data[, !(colnames(new_data) %in% col_names[i]), drop = FALSE]
+    }
 
     new_data <- vctrs::vec_cbind(new_data, tfidf_text)
   }
@@ -181,17 +194,17 @@ bake.step_tfidf <- function(object, new_data, ...) {
 #' @export
 print.step_tfidf <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Term frequency-inverse document frequency with ", sep = "")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Term frequency-inverse document frequency with "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_tfidf
+#' @rdname tidy.recipe
 #' @param x A `step_tfidf` object.
 #' @export
 tidy.step_tfidf <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$terms)
+    res <- tibble(terms = unname(x$columns))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names)
