@@ -1,5 +1,3 @@
-context("test-stopwords")
-
 library(recipes)
 library(textrecipes)
 
@@ -83,6 +81,56 @@ test_that("printing", {
   rec <- rec %>%
     step_tokenize(text) %>%
     step_stopwords(text)
-  expect_output(print(rec))
-  expect_output(prep(rec, verbose = TRUE))
+  expect_snapshot(print(rec))
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_stopwords(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked1)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_stopwords(rec)
+
+  expect_identical(
+    tidy(rec, number = 1),
+    tibble(
+      terms = character(),
+      value = character(),
+      keep = logical(),
+      id = character()
+    )
+  )
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(
+    tidy(rec, number = 1),
+    tibble(
+      terms = character(),
+      value = character(),
+      keep = logical(),
+      id = character()
+    )
+  )
+})
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_stopwords(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
 })
